# Streaming chatbot

This example shows how we can use the streaming API
to respond to return quicker results to the user and build a more
seamless interactive experience.

This is the same chatbot as the one in the `chatbot` example,
but it is built slightly differently (for streaming purposes).

## How to use

Run `streamlit run streamlit_app.py` from the command line and you will see the chatbot in action.
Open up the burr UI `burr` and you can track the chatbot
